==> react-native-wonder-amap-0.0.31.tgz: package/lib/ios/AMapManager.m <==
//
//  RCTAMapManager.m
//  RCTAMap
//
//  Created by 王继荣 on 20/07/2017.
//  Copyright © 2017 cn.wonderbear. All rights reserved.
//

#import "AMapManager.h"

@interface AMapManager()
{
    CLLocationManager *locationManager;
    AMapEventEmitter *eventEmitter;
    AMapNaviManager *naviManager;
}

@end

static AMapManager *sharedInstance;

@implementation AMapManager

RCT_EXPORT_MODULE()

- (instancetype)init
{
    self = [super init];
    if (self) {
        [AMapServices sharedServices].enableHTTPS = YES;
        NSString *plistPath = [[NSBundle mainBundle] pathForResource:@"Info" ofType:@"plist"];  
        NSMutableDictionary *dict = [[NSMutableDictionary alloc] initWithContentsOfFile:plistPath];
        NSString* apiKey = [ dict objectForKey:@"AMapApiKey" ];
        [AMapServices sharedServices].apiKey = apiKey;
        
        eventEmitter = [AMapEventEmitter new];
        
        naviManager = [AMapNaviManager new];
        
        locationManager = [CLLocationManager new];
        locationManager.delegate = self;
        locationManager.desiredAccuracy = kCLLocationAccuracyBest;
        [locationManager requestWhenInUseAuthorization];
        [locationManager startUpdatingLocation];
    }
    return self;
}

- (dispatch_queue_t)methodQueue
{
    return self.bridge.uiManager.methodQueue;
}

- (UIView *)view
{
    MAMapView *mapView = [MAMapView new];
    mapView.delegate = eventEmitter;
    mapView.showsCompass = NO;
    [mapView setZoomLevel:14];
    [mapView removeAnnotations:[mapView annotations]];
    
    return mapView;
}

- (void)dealloc {
    eventEmitter = nil;
    naviManager = nil;
    locationManager = nil;
}

RCT_CUSTOM_VIEW_PROPERTY(userTrackingMode, NSString, MAMapView)
{
    NSString *userTrackingMode = [RCTConvert NSString:json];
    if ([userTrackingMode isEqualToString:@"followHeading"]) {
        [view setUserTrackingMode: MAUserTrackingModeFollowWithHeading];
    } else if ([userTrackingMode isEqualToString:@"follow"]) {
        [view setUserTrackingMode: MAUserTrackingModeFollow];
    } else {
        [view setUserTrackingMode: MAUserTrackingModeNone];
    }
}

RCT_CUSTOM_VIEW_PROPERTY(showUserLocation, BOOL, MAMapView)
{
    [view setShowsUserLocation:[RCTConvert BOOL:json]];
}

RCT_EXPORT_VIEW_PROPERTY(showTraffic, BOOL)

RCT_EXPORT_METHOD(setCenterCoordinate: (nonnull NSNumber *)reactTag withCoordinate: (CLLocationCoordinate2D)coordinate withEdgePadding: (UIEdgeInsets)edgeInsets animated: (BOOL)animated)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            MACoordinateBounds bounds = MACoordinateBoundsMake(CLLocationCoordinate2DMake(coordinate.latitude - 0.04, coordinate.longitude + 0.04), CLLocationCoordinate2DMake(coordinate.latitude + 0.04, coordinate.longitude - 0.04));
            MAGroundOverlay *overlay = [MAGroundOverlay groundOverlayWithBounds:bounds icon:nil];
            [aMap setVisibleMapRect:overlay.boundingMapRect edgePadding:edgeInsets animated:animated];
        }
    }];
}

RCT_EXPORT_METHOD(reCenter: (nonnull NSNumber *)reactTag withEdgePadding: (UIEdgeInsets)edgeInsets animated: (BOOL)animated)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            MACoordinateBounds bounds = MACoordinateBoundsMake(CLLocationCoordinate2DMake(aMap.userLocation.coordinate.latitude - 0.04, aMap.userLocation.coordinate.longitude + 0.04), CLLocationCoordinate2DMake(aMap.userLocation.coordinate.latitude + 0.04, aMap.userLocation.coordinate.longitude - 0.04));
            MAGroundOverlay *overlay = [MAGroundOverlay groundOverlayWithBounds:bounds icon:nil];
            [aMap setVisibleMapRect:overlay.boundingMapRect edgePadding:edgeInsets animated:animated];
        }
    }];
}

RCT_EXPORT_METHOD(reloadMap: (nonnull NSNumber *)reactTag)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap reloadMap];
        }
    }];
}

RCT_EXPORT_METHOD(showAnnotations: (nonnull NSNumber *)reactTag withAnnotations: (nonnull NSArray<AMapAnnotation *> *)annotations)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap showAnnotations:annotations animated:true];
        }
    }];
}

RCT_EXPORT_METHOD(addAnnotation: (nonnull NSNumber *)reactTag withAnnotation: (nonnull AMapAnnotation *)annotation)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            annotation.title = @"hello";
            annotation.subtitle = @"world";
            [aMap addAnnotation:annotation];
        }
    }];
}

RCT_EXPORT_METHOD(addAnnotations: (nonnull NSNumber *)reactTag withAnnotations: (nonnull NSArray<AMapAnnotation *> *)annotations)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap addAnnotations:annotations];
        }
    }];
}

RCT_EXPORT_METHOD(removeAnnotation: (nonnull NSNumber *)reactTag withAnnotation: (nonnull AMapAnnotation *)annotation)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap removeAnnotation:annotation];
        }
    }];
}

RCT_EXPORT_METHOD(removeAnnotations: (nonnull NSNumber *)reactTag withAnnotations: (nonnull NSArray<AMapAnnotation *> *)annotations)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap removeAnnotations:annotations];
        }
    }];
}

RCT_EXPORT_METHOD(clearAnnotations: (nonnull NSNumber *)reactTag)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap removeAnnotations:[aMap annotations]];
        }
    }];
}

RCT_EXPORT_METHOD(selectAnnotation: (nonnull NSNumber *)reactTag withAnnotation: (nonnull AMapAnnotation *)annotation)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap selectAnnotation:annotation animated:true];
        }
    }];
}

RCT_EXPORT_METHOD(deselectAnnotation: (nonnull NSNumber *)reactTag withAnnotation: (nonnull AMapAnnotation *)annotation)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap deselectAnnotation:annotation animated:true];
        }
    }];
}

RCT_EXPORT_METHOD(naviTo: (nonnull NSNumber *)reactTag destination: (nonnull AMapNaviEndPoint*)destination) 
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            [naviManager naviTo:destination];
        }
    }];
}

RCT_EXPORT_METHOD(naviFromTo: (nonnull NSNumber *)reactTag from: (nonnull AMapNaviEndPoint*)source  to:(nonnull AMapNaviEndPoint*)destination) 
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            [naviManager naviFrom:source to:destination];
        }
    }];
}

#pragma mark - CLLocationManagerDelegate

- (void)locationManager:(CLLocationManager *)manager
    didUpdateToLocation:(CLLocation *)newLocation
           fromLocation:(CLLocation *)oldLocation
{
    
}

- (void)locationManager:(CLLocationManager *)manager
       didFailWithError:(NSError *)error
{
    //定位失败
    
}

@end

==> react-native-wonder-amap-0.0.36.tgz: package/lib/ios/AMapManager.m <==
//
//  RCTAMapManager.m
//  RCTAMap
//
//  Created by 王继荣 on 20/07/2017.
//  Copyright © 2017 cn.wonderbear. All rights reserved.
//

#import "AMapManager.h"

@interface AMapManager()
{
    CLLocationManager *locationManager;
    AMapEventEmitter *eventEmitter;
    AMapNaviManager *naviManager;
}

@end

static AMapManager *sharedInstance;

@implementation AMapManager

RCT_EXPORT_MODULE()

- (instancetype)init
{
    self = [super init];
    if (self) {
        [AMapServices sharedServices].enableHTTPS = YES;
        NSString *plistPath = [[NSBundle mainBundle] pathForResource:@"Info" ofType:@"plist"];  
        NSMutableDictionary *dict = [[NSMutableDictionary alloc] initWithContentsOfFile:plistPath];
        NSString* apiKey = [ dict objectForKey:@"AMapApiKey" ];
        [AMapServices sharedServices].apiKey = apiKey;
        
        eventEmitter = [AMapEventEmitter new];
        
        naviManager = [AMapNaviManager new];
        
        locationManager = [CLLocationManager new];
        locationManager.delegate = self;
        locationManager.desiredAccuracy = kCLLocationAccuracyBest;
        [locationManager requestWhenInUseAuthorization];
        [locationManager startUpdatingLocation];
    }
    return self;
}

- (dispatch_queue_t)methodQueue
{
    return self.bridge.uiManager.methodQueue;
}

- (UIView *)view
{
    MAMapView *mapView = [MAMapView new];
    mapView.delegate = eventEmitter;
    mapView.showsCompass = NO;
    [mapView setZoomLevel:14];
    [mapView removeAnnotations:[mapView annotations]];
    
    return mapView;
}

- (void)dealloc {
    eventEmitter = nil;
    naviManager = nil;
    locationManager = nil;
}

RCT_CUSTOM_VIEW_PROPERTY(userTrackingMode, NSString, MAMapView)
{
    NSString *userTrackingMode = [RCTConvert NSString:json];
    if ([userTrackingMode isEqualToString:@"followHeading"]) {
        [view setUserTrackingMode: MAUserTrackingModeFollowWithHeading];
    } else if ([userTrackingMode isEqualToString:@"follow"]) {
        [view setUserTrackingMode: MAUserTrackingModeFollow];
    } else {
        [view setUserTrackingMode: MAUserTrackingModeNone];
    }
}

RCT_CUSTOM_VIEW_PROPERTY(showUserLocation, BOOL, MAMapView)
{
    [view setShowsUserLocation:[RCTConvert BOOL:json]];
}

RCT_EXPORT_VIEW_PROPERTY(showTraffic, BOOL)

RCT_CUSTOM_VIEW_PROPERTY(center, CLLocationCoordinate2D, MAMapView)
{
    [view setCenterCoordinate:[RCTConvert CLLocationCoordinate2D:json] animated:true];
}

RCT_CUSTOM_VIEW_PROPERTY(edgeInsets, NSDictionary, MAMapView)
{
    
}

RCT_CUSTOM_VIEW_PROPERTY(zoom, NSNumber, MAMapView)
{
    [view setZoomLevel:[RCTConvert float:json] animated:true];
}

RCT_CUSTOM_VIEW_PROPERTY(centerAndZoom, NSDictionary, MAMapView)
{
    NSDictionary *dic = [RCTConvert NSDictionary:json];
    if (dic[@"center"] != nil && dic[@"zoom"] != nil) {
        [view setCenterCoordinate:[RCTConvert CLLocationCoordinate2D:dic[@"center"]] animated:true];
        [view setZoomLevel:[RCTConvert float:dic[@"zoom"]] animated:true];
    }
}

RCT_EXPORT_METHOD(setCenterWithEdgeInsets: (nonnull NSNumber *)reactTag withCoordinate: (CLLocationCoordinate2D)coordinate withEdgePadding: (UIEdgeInsets)edgeInsets animated: (BOOL)animated)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            MACoordinateBounds bounds = MACoordinateBoundsMake(CLLocationCoordinate2DMake(coordinate.latitude - 0.04, coordinate.longitude + 0.04), CLLocationCoordinate2DMake(coordinate.latitude + 0.04, coordinate.longitude - 0.04));
            MAGroundOverlay *overlay = [MAGroundOverlay groundOverlayWithBounds:bounds icon:nil];
            [aMap setVisibleMapRect:overlay.boundingMapRect edgePadding:edgeInsets animated:animated];
        }
    }];
}

RCT_EXPORT_METHOD(reCenterWithEdgeInsets: (nonnull NSNumber *)reactTag withEdgePadding: (UIEdgeInsets)edgeInsets animated: (BOOL)animated)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            MACoordinateBounds bounds = MACoordinateBoundsMake(CLLocationCoordinate2DMake(aMap.userLocation.coordinate.latitude - 0.04, aMap.userLocation.coordinate.longitude + 0.04), CLLocationCoordinate2DMake(aMap.userLocation.coordinate.latitude + 0.04, aMap.userLocation.coordinate.longitude - 0.04));
            MAGroundOverlay *overlay = [MAGroundOverlay groundOverlayWithBounds:bounds icon:nil];
            [aMap setVisibleMapRect:overlay.boundingMapRect edgePadding:edgeInsets animated:animated];
        }
    }];
}

RCT_EXPORT_METHOD(reloadMap: (nonnull NSNumber *)reactTag)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap reloadMap];
        }
    }];
}

RCT_EXPORT_METHOD(showAnnotations: (nonnull NSNumber *)reactTag withAnnotations: (nonnull NSArray<AMapAnnotation *> *)annotations)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap showAnnotations:annotations animated:true];
        }
    }];
}

RCT_EXPORT_METHOD(addAnnotation: (nonnull NSNumber *)reactTag withAnnotation: (nonnull AMapAnnotation *)annotation)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            annotation.title = @"hello";
            annotation.subtitle = @"world";
            [aMap addAnnotation:annotation];
        }
    }];
}

RCT_EXPORT_METHOD(addAnnotations: (nonnull NSNumber *)reactTag withAnnotations: (nonnull NSArray<AMapAnnotation *> *)annotations)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap addAnnotations:annotations];
        }
    }];
}

RCT_EXPORT_METHOD(removeAnnotation: (nonnull NSNumber *)reactTag withAnnotation: (nonnull AMapAnnotation *)annotation)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap removeAnnotation:annotation];
        }
    }];
}

RCT_EXPORT_METHOD(removeAnnotations: (nonnull NSNumber *)reactTag withAnnotations: (nonnull NSArray<AMapAnnotation *> *)annotations)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap removeAnnotations:annotations];
        }
    }];
}

RCT_EXPORT_METHOD(clearAnnotations: (nonnull NSNumber *)reactTag)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap removeAnnotations:[aMap annotations]];
        }
    }];
}

RCT_EXPORT_METHOD(selectAnnotation: (nonnull NSNumber *)reactTag withAnnotation: (nonnull AMapAnnotation *)annotation)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            for (AMapAnnotation *anno in aMap.annotations) {
                if (anno.annotationId == annotation.annotationId) {
                    [aMap selectAnnotation:anno animated:true];
                }
            }
        }
    }];
}

RCT_EXPORT_METHOD(deselectAnnotation: (nonnull NSNumber *)reactTag withAnnotation: (nonnull AMapAnnotation *)annotation)
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            MAMapView* aMap = (MAMapView*)view;
            [aMap deselectAnnotation:annotation animated:true];
        }
    }];
}

RCT_EXPORT_METHOD(naviTo: (nonnull NSNumber *)reactTag destination: (nonnull AMapNaviEndPoint*)destination) 
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            [naviManager naviTo:destination];
        }
    }];
}

RCT_EXPORT_METHOD(naviFromTo: (nonnull NSNumber *)reactTag from: (nonnull AMapNaviEndPoint*)source  to:(nonnull AMapNaviEndPoint*)destination) 
{
    [self.bridge.uiManager addUIBlock:^(RCTUIManager *uiManager, NSDictionary<NSNumber *, UIView *> *viewRegistry) {
        UIView *view = viewRegistry[reactTag];
        if (![view isKindOfClass:[MAMapView class]]) {
            RCTLog(@"expecting MAMapView, got: %@", view);
        }
        else {
            [naviManager naviFrom:source to:destination];
        }
    }];
}

#pragma mark - CLLocationManagerDelegate

- (void)locationManager:(CLLocationManager *)manager
    didUpdateToLocation:(CLLocation *)newLocation
           fromLocation:(CLLocation *)oldLocation
{
    
}

- (void)locationManager:(CLLocationManager *)manager
       didFailWithError:(NSError *)error
{
    //定位失败
    
}

@end
